package com.ruoyi.system.service;

import com.ruoyi.system.domain.Qiyekunnandengjibiao;
import java.util.List;

/**
 * 个人独资Service接口
 * 
 * @author xu
 * @date 2019-09-09
 */
public interface IQiyekunnandengjibiaoService 
{
    /**
     * 查询个人独资
     * 
     * @param chukouqn 个人独资ID
     * @return 个人独资
     */
    Qiyekunnandengjibiao selectQiyekunnandengjibiaoById(Long chukouqn);

    /**
     * 查询个人独资列表
     * 
     * @param qiyekunnandengjibiao 个人独资
     * @return 个人独资集合
     */
    List<Qiyekunnandengjibiao> selectQiyekunnandengjibiaoList(Qiyekunnandengjibiao qiyekunnandengjibiao);

    /**
     * 新增个人独资
     * 
     * @param qiyekunnandengjibiao 个人独资
     * @return 结果
     */
    int insertQiyekunnandengjibiao(Qiyekunnandengjibiao qiyekunnandengjibiao);

    /**
     * 修改个人独资
     * 
     * @param qiyekunnandengjibiao 个人独资
     * @return 结果
     */
    int updateQiyekunnandengjibiao(Qiyekunnandengjibiao qiyekunnandengjibiao);

    /**
     * 批量删除个人独资
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteQiyekunnandengjibiaoByIds(String ids);

    /**
     * 删除个人独资信息
     * 
     * @param chukouqn 个人独资ID
     * @return 结果
     */
    int deleteQiyekunnandengjibiaoById(Long chukouqn);
}
